Learn R Programming

vntrs (version 0.1.1)

interruption: Interrupt local search

Description

This function checks if the local search can be interrupted prematurely.

Usage

interruption(f, point, L, minimize)

Value

TRUE for premature interruption, FALSE if not.

Arguments

f

A function that computes value, gradient, and Hessian of the function to be optimized and returns them as a named list with elements value, gradient, and hessian.

point

The current location of the local search.

L

A list of identified optima which contains lists with

  • value and

  • argument

of each identified optimum.

minimize

If TRUE, f gets minimized. If FALSE, maximized.