Learn R Programming

vntrs (version 0.1.1)

unique_optimum: Check new optimum for uniqueness

Description

This function checks if a new optimum argument is not yet contained in L.

Usage

unique_optimum(L, argument, tolerance)

Value

A boolean. If TRUE, argument is not contained in L. If FALSE, argument is already contained in L.

Arguments

L

A list of identified optima which contains lists with

  • value and

  • argument

of each identified optimum.

argument

The argument of a candidate optimum.

tolerance

A non-negative numeric value. For an identified optimum and a candidate optimum, if all coordinate differences are smaller than tolerance, they are considered as equal.