This function checks if the local search can be interrupted prematurely.
interruption(f, point, L, minimize)TRUE for premature interruption, FALSE if not.
A function that computes value, gradient, and Hessian of the function to be
optimized and returns them as a named list with elements value,
gradient, and hessian.
The current location of the local search.
A list of identified optima which contains lists with
value and
argument
of each identified optimum.
If TRUE, f gets minimized. If FALSE, maximized.