This function checks if a new optimum argument is not yet contained
in L.
unique_optimum(L, argument, tolerance)A boolean. If TRUE, argument is not contained in L.
If FALSE, argument is already contained in L.
A list of identified optima which contains lists with
value and
argument
of each identified optimum.
The argument of a candidate optimum.
A non-negative numeric value. For an identified optimum and a candidate
optimum, if all coordinate differences are smaller than tolerance,
they are considered as equal.